@@ -1,20 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1+
 /*
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301 USA.
- *
- * Copyright 2018 Lubomir Rintel <lkundrak@v3.sk>
+ * Copyright (C) 2018 Lubomir Rintel <lkundrak@v3.sk>
  */
 
 #ifndef __NM_DEVICE_WPAN_H__
@@ -37,10 +23,16 @@ G_BEGIN_DECLS
 
 #define NM_DEVICE_WPAN_HW_ADDRESS "hw-address"
 
+/**
+ * NMDeviceWpan:
+ */
+typedef struct _NMDeviceWpanClass NMDeviceWpanClass;
+
 NM_AVAILABLE_IN_1_14
 GType nm_device_wpan_get_type (void);
 
 NM_AVAILABLE_IN_1_14
+NM_DEPRECATED_IN_1_24_FOR (nm_device_get_hw_address)
 const char *nm_device_wpan_get_hw_address (NMDeviceWpan *device);
 
 G_END_DECLS
